Pair

Type Alias Pair 

type Pair<'gcx> = (Option<ValueKey>, Option<&'gcx Expr<'gcx>>);
A place written by an assignment, paired with the expression it receives.

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 24 bytes